MoinMoin Supports You
=====================

Free Support
------------
You can get free support and information here:

* on our chat channels, see https://moinmo.in/MoinMoinChat
* on our wiki, see https://moinmo.in/ — please note that quite a lot of the content
  there is about Moin 1.x and does not apply to Moin2. One page has a lot
  of information about Moin2 and also links to all sorts of Moin2 resources:
  https://moinmo.in/MoinMoin2.0
* on our mailing list, see https://moinmo.in/MoinMoinMailingLists
* on GitHub: https://github.com/moinwiki/moin

.. note::
   All free support is done voluntarily by helpful MoinMoin community members.
   Thanks to everyone who is helping!

   If you enjoy or want to enjoy free community support, please also consider
   being an active part of the community and supporting it.


Commercial Support
------------------
As MoinMoin 2.0 is not released yet, there is no support for production
systems based on it.

If you want to discuss development topics, please contact the developers.


You Support MoinMoin
====================

Like to help others?
--------------------
Stay connected to IRC, our wiki, and the mailing list (see above), and help
others who are searching for support there.

Found a bug?
------------
* File a bug report on the issue tracker.
* Even better: fix the bug, submit a pull request with a unit test and a fix.

Have an idea?
-------------
* Discuss it on IRC and file a feature request.
* Even better: discuss and write some Python code implementing it.

Born to code?
-------------
* Help work on the Moin2 core so it gets released sooner.
* Help maintain Moin 1.9 until Moin2 is ready.

Loving UI / UX design?
----------------------
* Help us make Moin2 look and feel better!

Have good language or documentation skills?
-------------------------------------------
* If you are a native speaker of a language other than English, with a good
  understanding of English, consider helping improve the translation into
  your language. (Not yet for Moin2 — too early.) See also :doc:`translate`
* Improve the documentation (see below).
  Here is a list of all TODOs in this documentation:

.. todolist::
